import React from 'react';
import { Progress, Space } from 'antd';
import styles from './index.less';
import CountUp from 'react-countup';

export interface AreaBarItem {
  name: string;
  value?: number;
  count?: number;
  percentage: number;
  // unit?: string;
}

export interface AreaBarListProps {
  data: AreaBarItem[];
  showCount?: boolean;
  showPercentage?: boolean;
  height?: number;
  progressColor?: {
    from: string;
    to: string;
  };
  onClick?: (item: AreaBarItem, index: number) => void;
  unit?: string;
  percentageUnit?: string;
  percentageFixed?: number;
}

const AreaBarList: React.FC<AreaBarListProps> = ({
  data = [],
  showCount = true,
  showPercentage = true,
  height = 350,
  progressColor = { from: 'rgb(0, 185, 255)', to: 'rgb(121, 255, 209)' },
  // progressColor = { from: '#79FFD1', to: '#00B9FF' },
  onClick,
  percentageUnit = '%',
  unit = '件',
  percentageFixed = 1
}) => {
  return (
    <div className={styles.container} >
      {data.map((item, index) => (
        <div 
          key={index}
          className={styles.itemWrapper}
          onClick={() => onClick && onClick(item, index)}
        >
          <div className={styles.itemHeader}>
            <div className={styles.name}>{item.name}</div>
            <Space size={16} className={styles.valueWrapper}>
              {showCount && item.count !== undefined && (
                <div className={styles.valueGroup}>
                  <div className={styles.value}>
                    <span className={styles.valueNumber}>
                      <CountUp
                        end={Number(item.count)}
                        separator=","
                        decimals={0}
                      />
                    </span>
                  </div>
                  <div className={styles.unitWrapper}>
                    <span className={styles.valueUnit}>{unit}</span>
                  </div>
                </div>
              )}
              {showPercentage && (
                <div className={styles.valueGroup}>
                  <div className={styles.value}>
                    <span className={styles.valueNumber}>
                      <CountUp
                        end={Number(item.percentage ? Number(item.percentage).toFixed(percentageFixed) : 0)}
                        separator=","
                        decimals={percentageFixed}
                      />
                    </span>
                  </div>
                  <div className={styles.unitWrapper}>
                    <span className={styles.valueUnit}>{percentageUnit}</span>
                  </div>
                </div>
              )}
            </Space>
          </div>
          <Progress
            className={styles.progress}
            percent={item.percentage}
            showInfo={false}
            strokeColor={{ from: progressColor.from, to: progressColor.to }}
            status="active"
            size={{ height: 12 }}
          />
        </div>
      ))}
    </div>
  );
};

export default AreaBarList; 